@@ -29,6 +29,6 @@ extern "C" {
         dest_width: u16,
         dest_height: u16,
     );
-    pub fn qwac_data_store(data: *const u8, size: u32);
+    pub fn qwac_data_save(data: *const u8, size: u32);
     pub fn qwac_data_load(data: *mut u8, size: u32) -> u32;
 }
