@@ -36,7 +36,7 @@ pub struct Color {
 
 pub trait Game {
     /// Create a new Game of this type, starting at the given time in seconds.
-    fn new(timestamp: i64) -> Self;
+    fn new(timestamp: f64) -> Self;
 
     /// Handle an input event.
     fn event(&mut self, event: event::Event);
@@ -53,7 +53,7 @@ macro_rules! qwac_game {
         static mut QWAC_RUST_GAME: Option<$game_type> = None;
 
         #[no_mangle]
-        pub extern "C" fn qwac_game_create(timestamp: i64) -> *mut $game_type {
+        pub extern "C" fn qwac_game_create(timestamp: f64) -> *mut $game_type {
             let game = <$game_type as $crate::Game>::new(timestamp);
 
             #[cfg(not(feature = "alloc"))]
